'use strict';
var login = require('../services/loginService.js');
const { body,check } = require('express-validator')

exports.validate = (method) => {
  switch (method) {
    case 'register': {
     return [
     body('name', 'name is required.').not().isEmpty(),
     body('email', 'email is required.').not().isEmpty(),
     body('email', 'Your email is not valid').not().isEmpty().isEmail().normalizeEmail(),
     body('password', 'Password is required.').not().isEmpty(),
     body('email').custom(value => {
       if(value != '' && typeof value != 'undefined'){
        return login.checkValidEmail(value,function(err, result){
         if(err){
          throw new Error("This email is already exist.");
        }else{
          if(result.status == false){
           throw new Error('This email is already exist.');
         }
       }
     });
      }else{
        return true; 
      }
    }),
     ]
   }
   case 'new-register': {
     return [
     body('first_name', 'first name is required.').not().isEmpty(),

     body('last_name', 'last name is required.').not().isEmpty(),

     body('longitude', 'longitude is required.').not().isEmpty(),

     body('latitude', 'latitude is required.').not().isEmpty(),

     body('role_id', 'role id is required.').not().isEmpty(),

     body('state', 'state is required.').not().isEmpty(),

     body('country', 'country is required.').not().isEmpty(),

     body('city', 'city is required.').not().isEmpty(),

     body('address', 'address is required.').not().isEmpty(),
     //body('email', 'Your email is not valid').not().isEmpty().isEmail(),

     body('password', 'Password is required.').not().isEmpty(),

     body('mobile_number', 'mobile number is required.').not().isEmpty(),

     body('mobile_number', 'mobile number is not valid.').not().isAlpha(),

     body('mobile_number').custom(value => {

      if(value != '' && typeof value != 'undefined'){

        return login.checkValidMobileNumber(value,function(err, result){
          if(err){
            throw new Error("This mobile number is already exist.");
          }else{
            if(result.status == false){
              throw new Error('This mobile number is already exist.');
            }
          }
        });
      }else{
        return true; 
      }
    }),
/*

     body('email').custom(value => {
      if(value != '' && typeof value != 'undefined'){
        return login.checkValidEmail(value,function(err, result){
          if(err){
            throw new Error("This email is already exist.");
          }else{
            if(result.status == false){
              throw new Error('This email is already exist.');
            }
          }
        });
      }else{
        return true; 
      }
    }),*/

     ]
   }
   case 'accountVerification': {
     return [
     check('validate_string', 'Validate String is required.').not().isEmpty(),
     check('validate_string').custom(value => {
       if(value != '' && typeof value != 'undefined'){
        return login.checkValidValidateString(value,function(err, result){

         if(err){
          throw new Error("This link is invalid.");
        }else{
          if(result.status == false){
           throw new Error("This link is invalid");
         }
       }
     });
      }else{
        return true; 
      }
    }),
     ]
   }
   case 'signin': {
     return [
     body('email', 'Username is required.').not().isEmpty(),
     body('password', 'Password is required.').not().isEmpty(),
     ]
   }
   case 'forgot-password': {
     return [
     body('mobile_number', 'Mobile number is required.').not().isEmpty(),
     ]
   }
   case 'send-otp': {
     return [
     body('mobile_number', 'Mobile number is required.').not().isEmpty(),
     ]
   }
   
   case 'match-otp': {
     return [
     body('mobile_number', 'Mobile number is required.').not().isEmpty(),
     body('otp', 'OTP is required.').not().isEmpty(),
     ]
   }

   case 'sign-match-otp': {
     return [
     body('mobile_number', 'Mobile number is required.').not().isEmpty(),
     body('otp', 'OTP is required.').not().isEmpty(),
     ]
   }

   case 'reset-password': {
     return [
     body('new_password', 'New Password is required.').not().isEmpty(),
     ]
   }
 }
}

const { validationResult } = require('express-validator');

exports.newRegister = function(req, res){

  const errors = validationResult(req);

  if (!errors.isEmpty()){
    res.status(200).json({  status:'error',errors: errors.array() });
    return;
  }
  login.newRegister(req.body,function(err, result){
    if (err)
      res.send(err);
    res.json(result);
  });
};

exports.register = function(req, res){
  const errors = validationResult(req);
  if (!errors.isEmpty()){
    res.status(200).json({  status:'error',errors: errors.array() });
    return;
  }
  login.register(req.body,function(err, result){
    if (err)
      res.send(err);
    res.json(result);
  });
};

exports.accountVerification = function(req, res){
  //console.log(req.query)
  const errors = validationResult(req);
  if (!errors.isEmpty()){
    res.status(200).json({  status:'error',errors: errors.array() });
    return;
  }
  login.accountVerificationService(req.query.validate_string,function(err, result){
    if (err)
      res.send(err);
    res.json(result);
  });
};

exports.signin = function(req, res){
  const errors = validationResult(req);
  if (!errors.isEmpty()){
    res.status(422).json({  status:'error',errors: errors.array() });
    return;
  }
  login.signin(req.body.email,req.body,function(err, result){
    if (err)
      res.send(err);
    res.json(result);
  });
};

exports.admin_signin = function(req, res){
  const errors = validationResult(req);
  if (!errors.isEmpty()){
    res.status(422).json({errors: errors.array() });
    return;
  }
  login.admin_signin(req.body.email,req.body.password,function(err, result){
    if (err)
      res.send(err);
    res.json(result);
  });
};

exports.forgotPassword = function(req, res){
  login.forgotPassword(req.body,function(err, result){
    if (err)
      res.send(err);
    res.json(result);
  });
};

exports.logout = function(req, res){
  login.logout(req.body,function(err, result){
    if (err)
      res.send(err);
    res.json(result);
  });
};

exports.reset_password = function(req, res){
  const errors = validationResult(req);
  if (!errors.isEmpty()){
    res.status(200).json({  status:'error',errors: errors.array() });
    return;
  }
  login.reset_password(req.body,function(err, result){
    if (err)
      res.send(err);
    res.json(result);
  });
};

exports.send_otp = function(req, res){
  const errors = validationResult(req);
  if (!errors.isEmpty()){
    res.status(200).json({  status:'error',errors: errors.array() });
    return;
  }
  login.send_otp(req.body,function(err, result){
    if (err)
      res.send(err);
    res.json(result);
  });
};

exports.match_otp = function(req, res){
  const errors = validationResult(req);
  if (!errors.isEmpty()){
    res.status(200).json({  status:'error',errors: errors.array() });
    return;
  }
  login.match_otp(req.body,function(err, result){
    if (err)
      res.send(err);
    res.json(result);
  });
};

exports.sign_match_otp = function(req, res){
  const errors = validationResult(req);
  if (!errors.isEmpty()){
    res.status(200).json({  status:'error',errors: errors.array() });
    return;
  }
  login.sign_match_otp(req.body,function(err, result){
    if (err)
      res.send(err);
    res.json(result);
  });
};
