'use strict';
var sql = require('./../../conf/db.js');
module.exports = function(app) {

  app.use(function(req, res, next) {
    res.header("Access-Control-Allow-Origin", "*");
    res.header("Access-Control-Allow-Headers", "Origin, X-Requested-With, Content-Type, Accept");
    next();
  }); 

  var login = require('../controllers/loginController');
  var user = require('../controllers/userController');
  var emailManager = require('../controllers/emailManagerController');
  var emailLogs = require('../controllers/emailLogsController');
  var plan = require('../controllers/planController');
  var staff = require('../controllers/staffController');
  var waiter = require('../controllers/waiterController'); 
  var setting = require('../controllers/settingController');
  var restaurant = require('../controllers/restaurantController');
  var employee = require('../controllers/employeeController');
  var vatCode = require('../controllers/vatCodeController');
  var account = require('../controllers/accountController');
  var category = require('../controllers/categoryController');
  var cashDetail = require('../controllers/cashDetailController');
  var paymentMethod = require('../controllers/paymentMethodController');
  var paymentType = require('../controllers/paymentTypeController');
  var staffSales = require('../controllers/staffSalesController');
  var dailyReport = require('../controllers/dailyReportController');
  var subAdmin = require('../controllers/subAdminController');
  
 // app.post('/register', login.validate('register'), login.register);

 /*used api in mcfincap app*/
 app.post('/register', login.validate('new-register'), login.newRegister);
 app.post('/signin', login.validate('signin'), login.signin);
 app.post('/send-otp' , login.validate('send-otp'), login.send_otp);
 app.post('/match-otp' , login.validate('match-otp'), login.match_otp);

 app.post('/sign_match_otp' , login.validate('sign-match-otp'), login.sign_match_otp);
 
 app.post('/reset-password', login.validate('reset-password'), login.reset_password);
 app.post('/logout', login.logout);

 //app.post('/forgot-password' , login.validate('forgot-password'), login.forgotPassword);


 app.post('/admin_signin', login.validate('signin'), login.admin_signin);
 app.get('/account-verification', login.validate('accountVerification'), login.accountVerification);

  //User
  app.post('/upload',user.validate('upload'), user.upload);
  app.post('/upload_profile_pic', user.upload_profile_pic);
  
  app.post('/apply_loan',user.validate('apply_loan'), user.applyLoan);
  app.post('/create_lead' , user.create_lead);

  app.post('/loan_list',user.listLoan);
  app.post('/active_lead_list',user.active_lead_list);
  app.post('/active_lead_list_filter',user.active_lead_list_filter);
  app.post('/get_active_lead_data',user.get_active_lead_data);
  app.post('/assigned_lead_list',user.assigned_lead_list);
  app.post('/get_assigned_lead_data',user.get_assigned_lead_data);
  app.post('/assigned_lead_list_filter',user.assigned_lead_list_filter);

  app.post('/loan_management',user.loanManagement);

  app.post('/get_lanaguage', user.get_language);
  app.post('/get_notification', user.get_notification);

  app.post('/set_lanaguage' ,user.validate('set-language'), user.set_language);
  app.post('/get_cms' , user.get_cms);

  app.post('/update_profile' ,user.validate('update_profile'), user.update_profile);
  app.post('/get_profile' , user.get_profile);


  app.post('/check_token', user.checkToken);
  app.post('/get_user', user.get_user);
  app.post('/update_user', user.update_user);
  app.post('/change_password',user.validate('change_password'), user.change_password);

  //Staff
  app.post('/add_staff',staff.validate('add_staff'), staff.add_staff);
  app.post('/staff_list', staff.staff_list);
  app.post('/update_staff', staff.update_staff);
  app.post('/delete_staff', staff.delete_staff);

  //Waiter
  app.post('/waiter_list', waiter.waiter_list);
  app.post('/update_waiter', waiter.update_waiter);
  app.post('/delete_waiter', waiter.delete_waiter);
  app.post('/add_waiter',waiter.validate('add_waiter'), waiter.add_waiter);

  //Email Manager
  app.post('/add_email_template',emailManager.validate('add_email_template'), emailManager.add_email_template);
  app.post('/update_email_template', emailManager.update_email_template);
  app.post('/email_template_list', emailManager.email_template_list);
  app.post('/delete_email_template', emailManager.delete_email_template);
  app.post('/get_email_template', emailManager.get_email_template);
  app.post('/get_email_actions', emailManager.get_email_actions);
  app.post('/get_options_by_action', emailManager.get_options_by_action);

  //Email Logs
  app.post('/get_email_log', emailLogs.get_email_log);
  app.post('/email_logs_list', emailLogs.email_logs_list);

  //Plan 
  app.post('/add_plan',plan.validate('add_plan'), plan.add_plan);
  app.post('/plan_list', plan.plan_list);
  app.get('/load_plans', plan.loadPlans);
  app.post('/get_plan', plan.get_plan);
  app.post('/get_user_plans', plan.getUserPlans);
  app.post('/get_user_plans_logs', plan.getUserPlansLogs);
  app.post('/get_current_plan', plan.getCurrentPlan);
  app.get('/select_plan/', plan.selectPlan);
  app.post('/update_plan', plan.update_plan);
  app.post('/update_user_plan', plan.update_user_plan);
  app.post('/delete_plan', plan.delete_plan);
  app.post('/delete_user_plan', plan.delete_user_plan);
  app.post('/add_user_plan', plan.addUserPlan);
  app.post('/save_plan_user', plan.savePlanUser);
  app.post('/get_plan_history', plan.getPlanHistory);

  //Setting 


  app.post('/get_setting', setting.getSetting);



  //app.post('/add_setting',setting.validate('addSetting'), setting.addSetting);

  //restaurant
  app.post('/restaurant_list', restaurant.restaurant_list);
  app.post('/get_restaurant', restaurant.getRestaurant);
  app.post('/delete_restaurant', restaurant.delete_restaurant);
  app.post('/toggle_restaurant_status', restaurant.toggleRestaurantStatus);

  //employee
  app.post('/add_employee', employee.add_employee);
  app.post('/employee_list', employee.employee_list);
  app.post('/update_employee', employee.update_employee);
  app.post('/get_employee', employee.get_employee);
  app.post('/delete_employee', employee.delete_employee);

  //Vat Code
  app.post('/add_vat_code',vatCode.addVatCode);
  app.post('/edit_vat_code',vatCode.editVatCode);
  app.post('/get_vat_code',vatCode.getVatCode);
  app.post('/list_vat_codes',vatCode.listVatCodes);
  app.post('/delete_vat_code',vatCode.deleteVatCode);

  //Accounts
  app.post('/add_account',account.addAccount);
  app.post('/edit_account',account.editAccount);
  app.get('/get_account',account.getAccount);
  app.post('/list_accounts',account.listAccounts);
  app.get('/delete_account',account.deleteAccount);  

  //Categories
  app.post('/add_category',category.addCategory);
  app.post('/edit_category',category.editCategory);
  app.get('/get_category/',category.getCategory);
  app.post('/list_categories',category.listCategories);
  app.get('/delete_category',category.deleteCategory);  

  //Cash Details
  app.post('/add_cash_detail',cashDetail.addCashDetail);
  app.post('/edit_cash_detail',cashDetail.updateCashDetail);
  app.get('/get_cash_detail/',cashDetail.getCashDetail);
  app.post('/list_cash_details',cashDetail.listCashDetails);
  app.get('/delete_cash_detail',cashDetail.deleteCashDetail);  

  //Payment Methods
  app.post('/add_payment_method',paymentMethod.addPaymentMethod);
  app.post('/edit_payment_method',paymentMethod.updatePaymentMethod);
  app.get('/get_payment_method/',paymentMethod.getPaymentMethod);
  app.post('/list_payment_methods',paymentMethod.listPaymentMethods);
  app.get('/delete_payment_method',paymentMethod.deletePaymentMethod);  

  //Payment Types
  app.post('/add_payment_type',paymentType.addPaymentType);
  app.post('/edit_payment_type',paymentType.updatePaymentType);
  app.get('/get_payment_type/',paymentType.getPaymentType);
  app.post('/list_payment_types',paymentType.listPaymentTypes);
  app.get('/delete_payment_type',paymentType.deletePaymentType);  

  //Staff Sales
  app.post('/add_staff_sales',staffSales.addStaffSales);
  app.post('/list_staff_sales',staffSales.listStaffSales);
  app.get('/get_staff_sales/',staffSales.getStaffSales);
  app.post('/edit_staff_sales',staffSales.updateStaffSales);  
  app.get('/delete_staff_sales',staffSales.deleteStaffSales);  

  //Daily Report Book
  app.get('/get_report_dates',dailyReport.getReportDates);
  app.post('/add_daily_report',dailyReport.addDailyReport);
  app.post('/list_daily_report',dailyReport.listDailyReport);
  app.get('/get_daily_report/',dailyReport.getDailyReport);
  app.post('/edit_daily_report',dailyReport.updateDailyReport);  
  app.get('/delete_daily_report',dailyReport.deleteDailyReport);  

  //Sub Admin
  app.post('/add_sub_admin', subAdmin.add_sub_admin);
  app.post('/sub_admin_list', subAdmin.sub_admin_list);
  app.post('/update_sub_admin', subAdmin.update_sub_admin);
  app.post('/delete_sub_admin', subAdmin.delete_sub_admin);

  app.post('/check_password',user.validate('check_password'), user.check_password);


  

};